@@ -35,12 +35,12 @@ struct Ext;
 struct BaseNameExtensions;
 
 #define COPYQ_MIME_PREFIX_ITEMSYNC COPYQ_MIME_PREFIX "itemsync-"
-extern const char mimeExtensionMap[];
-extern const char mimeBaseName[];
-extern const char mimeNoSave[];
-extern const char mimeSyncPath[];
-extern const char mimeNoFormat[];
-extern const char mimeUnknownFormats[];
+extern const QLatin1String mimeExtensionMap;
+extern const QLatin1String mimeBaseName;
+extern const QLatin1String mimeNoSave;
+extern const QLatin1String mimeSyncPath;
+extern const QLatin1String mimeNoFormat;
+extern const QLatin1String mimeUnknownFormats;
 
 struct FileFormat {
     bool isValid() const { return !extensions.isEmpty(); }
@@ -69,7 +69,7 @@ public:
     static Hash calculateHash(const QByteArray &bytes);
 
     FileWatcher(const QString &path, const QStringList &paths, QAbstractItemModel *model,
-                int maxItems, const QList<FileFormat> &formatSettings, QObject *parent);
+                int maxItems, const QList<FileFormat> &formatSettings, QObject *parent = nullptr);
 
     const QString &path() const { return m_path; }
 
@@ -79,9 +79,10 @@ public:
 
     void unlock();
 
-    void createItemFromFiles(const QDir &dir, const BaseNameExtensions &baseNameWithExts, int targetRow);
+    QVariantMap itemDataFromFiles(const QDir &dir, const BaseNameExtensions &baseNameWithExts);
 
-    void createItemsFromFiles(const QDir &dir, const BaseNameExtensionsList &fileList);
+    void prependItemsFromFiles(const QDir &dir, const BaseNameExtensionsList &fileList);
+    void insertItemsFromFiles(const QDir &dir, const BaseNameExtensionsList &fileList);
 
     /**
      * Check for new files.
@@ -115,7 +116,7 @@ private:
 
     IndexData &indexData(const QModelIndex &index);
 
-    void createItem(const QVariantMap &dataMap, int targetRow);
+    void createItems(const QVector<QVariantMap> &dataMaps, int targetRow);
 
     void updateIndexData(const QModelIndex &index, const QVariantMap &itemData);
 
