@@ -442,8 +442,6 @@ struct native_notifications : Config<bool> {
 class AppConfig final
 {
 public:
-    explicit AppConfig();
-
     QVariant option(const QString &name) const;
 
     template <typename T>
@@ -464,6 +462,8 @@ public:
 
     void removeOption(const QString &name);
 
+    Settings &settings() { return m_settings; }
+
 private:
     Settings m_settings;
 };
