@@ -77,8 +77,6 @@ public:
     /** Return tab names. */
     QStringList tabs() const;
 
-    void moveTab(int from, int to);
-
     void addToolBars(QMainWindow *mainWindow);
 
     void saveTabInfo();
@@ -96,6 +94,8 @@ public:
     void setTreeModeEnabled(bool enabled);
     void setTabItemCount(const QString &tabName, int itemCount);
 
+    void setTabsOrder(const QStringList &tabs);
+
 signals:
     /// Tabs moved in tab bar.
     void tabMoved(int from, int to);
@@ -123,6 +123,8 @@ private:
     void updateTabItemCount(const QString &name);
     QString itemCountLabel(const QString &name);
 
+    void setTreeModeEnabled(bool enabled, const QStringList &tabs);
+
     QToolBar *m_toolBar;
     QToolBar *m_toolBarTree;
     QToolBar *m_toolBarCurrent;
